@@ -343,7 +343,9 @@ class CentralUnitAPI:
                         modes=[
                             ThermostatMode(mode) for mode in item[ApiAttribute.MODES]
                         ],
-                        unit=ThermostatTemperatureUnit(item[ApiAttribute.TEMPERATURE_UNITS]),
+                        unit=ThermostatTemperatureUnit(
+                            item[ApiAttribute.TEMPERATURE_UNITS]
+                        ),
                     )
                 # add rolling scenario
                 elif device_type == DeviceType.RollingScenario.value:
@@ -410,12 +412,12 @@ class CentralUnitAPI:
                 self._devices_map[device_id].state = device_state[ApiAttribute.STATE][
                     ApiAttribute.POWER
                 ]
-                self._devices_map[device_id].mode = ThermostatMode(device_state[ApiAttribute.STATE][
-                    ApiAttribute.MODE
-                ])
-                self._devices_map[device_id].fan = ThermostatFanSpeed(device_state[ApiAttribute.STATE][
-                    ApiAttribute.FAN
-                ])
+                self._devices_map[device_id].mode = ThermostatMode(
+                    device_state[ApiAttribute.STATE][ApiAttribute.MODE]
+                )
+                self._devices_map[device_id].fan = ThermostatFanSpeed(
+                    device_state[ApiAttribute.STATE][ApiAttribute.FAN]
+                )
                 self._devices_map[device_id].target_temperature = device_state[
                     ApiAttribute.STATE
                 ][ApiAttribute.CONFIGURED_TEMPERATURE]
